==> maven-plugin-testing-3.4.0-source-release.zip: maven-plugin-testing-3.4.0/maven-plugin-testing-harness/src/test/java/org/apache/maven/plugin/testing/ProvidesInjectOverrideMojoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugin.testing;

import java.util.Properties;

import org.apache.maven.api.di.Provides;
import org.apache.maven.api.plugin.testing.InjectMojo;
import org.apache.maven.api.plugin.testing.MojoTest;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.plugin.MojoExecution;
import org.apache.maven.project.MavenProject;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertSame;
import static org.mockito.Mockito.when;

@ExtendWith(MockitoExtension.class)
@MojoTest
class ProvidesInjectOverrideMojoTest {

    private static final String POM = "<project></project>";

    @Mock
    private MavenProject project;

    @Mock
    private MavenSession session;

    @Mock
    private MojoExecution mojoExecution;

    @BeforeEach
    void setup() {
        when(session.getUserProperties()).thenReturn(new Properties());
        when(session.getSystemProperties()).thenReturn(new Properties());
    }

    @Provides
    public MavenProject mockMavenProject() {
        return project;
    }

    @Provides
    public MavenSession mockMavenSession() {
        return session;
    }

    @Provides
    MojoExecution mockMojoExecution() {
        return mojoExecution;
    }

    @Test
    @InjectMojo(pom = POM, goal = "test:test-plugin:0.0.1-SNAPSHOT:provides")
    public void bennShouldBeInjected(ProvidesInjectMojo mojo) {
        assertNotNull(mojo);
        // session provided by the @Provides method should be used
        assertSame(session, mojo.getSession());
        assertSame(session, mojo.getSessionFromBean());

        assertSame(project, mojo.getProject());
        assertSame(project, mojo.getProjectFromBean());

        assertSame(mojoExecution, mojo.getMojoExecution());
        assertSame(mojoExecution, mojo.getMojoExecutionFromBean());
    }
}

==> maven-plugin-testing-3.5.0-source-release.zip: maven-plugin-testing-3.5.0/maven-plugin-testing-harness/src/test/java/org/apache/maven/plugin/testing/ProvidesInjectOverrideMojoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugin.testing;

import java.util.Properties;

import org.apache.maven.api.di.Provides;
import org.apache.maven.api.plugin.testing.InjectMojo;
import org.apache.maven.api.plugin.testing.MojoTest;
import org.apache.maven.execution.MavenSession;
import org.apache.maven.plugin.MojoExecution;
import org.apache.maven.project.MavenProject;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertSame;
import static org.mockito.Mockito.when;

@ExtendWith(MockitoExtension.class)
@MojoTest
class ProvidesInjectOverrideMojoTest {

    private static final String POM = "<project></project>";

    @Mock
    private MavenProject project;

    @Mock
    private MavenSession session;

    @Mock
    private MojoExecution mojoExecution;

    @BeforeEach
    void setup() {
        when(session.getUserProperties()).thenReturn(new Properties());
        when(session.getSystemProperties()).thenReturn(new Properties());
    }

    @Provides
    public MavenProject mockMavenProject() {
        return project;
    }

    @Provides
    public MavenSession mockMavenSession() {
        return session;
    }

    @Provides
    MojoExecution mockMojoExecution() {
        return mojoExecution;
    }

    @Test
    @InjectMojo(pom = POM, goal = "test:test-plugin:0.0.1-SNAPSHOT:provides")
    void bennShouldBeInjected(ProvidesInjectMojo mojo) {
        assertNotNull(mojo);
        // session provided by the @Provides method should be used
        assertSame(session, mojo.getSession());
        assertSame(session, mojo.getSessionFromBean());

        assertSame(project, mojo.getProject());
        assertSame(project, mojo.getProjectFromBean());

        assertSame(mojoExecution, mojo.getMojoExecution());
        assertSame(mojoExecution, mojo.getMojoExecutionFromBean());
    }

    @Nested
    class NestedTest {

        @Mock
        private MavenProject nestedProject;

        @Provides
        public MavenProject mockMavenProject() {
            return nestedProject;
        }

        @Test
        @InjectMojo(pom = POM, goal = "test:test-plugin:0.0.1-SNAPSHOT:provides")
        void bennFromParentClassShouldBeInjected(ProvidesInjectMojo mojo) {

            assertNotNull(mojo);
            // session provided by the @Provides method should be used
            assertSame(session, mojo.getSession());
            assertSame(session, mojo.getSessionFromBean());

            assertSame(nestedProject, mojo.getProject());
            assertSame(nestedProject, mojo.getProjectFromBean());

            assertSame(mojoExecution, mojo.getMojoExecution());
            assertSame(mojoExecution, mojo.getMojoExecutionFromBean());
        }
    }
}
